@@ -775,7 +775,7 @@ def getFeeSheet(text: str, cnum: str):
 		drows = fees_noalpha.map(lambda x: x.replace(",","").split("$"))
 		coderows = srows.map(lambda x: str(x[5]).strip() if len(x)>5 else "")
 		payorrows = srows.map(lambda x: str(x[6]).strip() if len(x)>6 else "")
-		payorrows = payorrows.map(lambda x: re.sub(r'(\$\d{1,2}?\.{1}\d{2}+)','',x))
+		# payorrows = payorrows.map(lambda x: re.sub(r'(\$\d{1,2}?\.{1}\d{2}+)','',x))
 		amtduerows = drows.map(lambda x: str(x[1]).strip() if len(x)>1 else "")
 		amtpaidrows = drows.map(lambda x: str(x[2]).strip() if len(x)>2 else "")
 		balancerows = drows.map(lambda x: str(x[-1]).strip() if len(x)>5 else "")
@@ -901,7 +901,10 @@ def getCharges(text: str, cnum: str):
 	charges['DescFix'] = charges.index.map(lambda x: len(charges['Description'][x]) - len(charges['Desc2'][x]))
 	charges['DescFix'] = charges.index.map(lambda x: True if charges['Description'][x].strip() == "FELONY PROPERTY" else charges['DescFix'][x])
 	charges['Description'] = charges.index.map(lambda x: re.split(r'.{3}-.{3}-.{3}',charges.Charges[x])[0] if charges.DescFix[x] > 0 else charges['Description'][x])
-	charges['Description'] = charges.index.map(lambda x: re.sub(r'(\d{3}\s[\w\d]{4})','',x) if bool(re.search(r'(\d{3}\s[\w\d]{4})',x)) else x)
+	try:
+		charges['Description'] = charges.index.map(lambda x: re.sub(r'(\d{3}\s[\w\d]{4})','',str(x)) if bool(re.search(r'(\d{3}\s[\w\d]{4})',str(x))) else str(x))
+	except TypeError:
+		pass
 	charges.drop(columns=['Desc2','DescFix'],inplace=True)
 
 	###
